# author: @netmanchris
# -*- coding: utf-8 -*-
"""
This module contains functions for working with the access point information
capabilities of the HPE IMC WSM Module using the RESTful API

"""

# This section imports required libraries
import json

import requests

from pyhpeimc.auth import HEADERS


def get_ap_info_all(auth, url):
    """
    function takes no input to RESTFUL call to HP IMC
    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single wireless
    access point which has been
    discovered in the HPE IMC WSM module

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.apinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> all_ap_info = get_ap_info_all(auth.creds, auth.url)

    >>> assert type(all_ap_info) is list

    >>> assert len(all_ap_info[0]) == 19

    >>> assert 'acDevId' in all_ap_info[0]

    >>> assert 'acIpAddress' in all_ap_info[0]

    >>> assert 'acLabel' in all_ap_info[0]

    >>> assert 'apAlias' in all_ap_info[0]

    >>> assert 'connectType' in all_ap_info[0]

    >>> assert 'hardwareVersion' in all_ap_info[0]

    >>> assert 'ipAddress' in all_ap_info[0]

    >>> assert 'isFit' in all_ap_info[0]

    >>> assert 'label' in all_ap_info[0]

    >>> assert 'location' in all_ap_info[0]

    >>> assert 'macAddress' in all_ap_info[0]

    >>> assert 'onlineClientCount' in all_ap_info[0]

    >>> assert 'onlineStatus' in all_ap_info[0]

    >>> assert 'serialId' in all_ap_info[0]

    >>> assert 'softwareVersion' in all_ap_info[0]

    >>> assert 'ssids' in all_ap_info[0]

    >>> assert 'status' in all_ap_info[0]

    >>> assert 'type' in all_ap_info[0]

    >>> assert 'sysName' in all_ap_info[0]

    """
    f_url = url + "/imcrs/wlan/apInfo/queryApBasicInfo"
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['apBasicInfo']
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_ap_info_all: An Error has occured"


def get_ap_info(ipaddress, auth, url):
    """
    function takes input of ipaddress to RESTFUL call to HP IMC

    :param ipaddress: The current IP address of the Access Point at time of query.

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: Dictionary object with the details of the target access point

    :rtype: dict

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.apinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> ap_info = get_ap_info('10.101.0.170',auth.creds, auth.url)

    >>> assert type(ap_info) is dict

    >>> assert len(ap_info) == 20

    >>> assert 'acDevId' in ap_info

    >>> assert 'acIpAddress' in ap_info

    >>> assert 'acLabel' in ap_info

    >>> assert 'apAlias' in ap_info

    >>> assert 'connectType' in ap_info

    >>> assert 'hardwareVersion' in ap_info

    >>> assert 'ipAddress' in ap_info

    >>> assert 'isFit' in ap_info

    >>> assert 'label' in ap_info

    >>> assert 'location' in ap_info

    >>> assert 'locationList' in ap_info

    >>> assert 'macAddress' in ap_info

    >>> assert 'onlineClientCount' in ap_info

    >>> assert 'serialId' in ap_info

    >>> assert 'softwareVersion' in ap_info

    >>> assert 'ssids' in ap_info

    >>> assert 'status' in ap_info

    >>> assert 'sysName' in ap_info

    >>> assert 'type' in ap_info

    """
    get_ap_info_url = "/imcrs/wlan/apInfo/queryApBasicInfoByCondition?ipAddress=" + str(ipaddress)
    f_url = url + get_ap_info_url
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['apBasicInfo']
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_ap_info_all: An Error has occured"



#!/usr/bin/env python3
# coding=utf-8
# author: @netmanchris
# -*- coding: utf-8 -*-
"""
This module contains functions for working with the Virtual Resource Manager
capabilities of the HPE IMC NMS platform using the RESTful API
"""


# This section imports required libraries

import json

import requests

from pyhpeimc.auth import HEADERS
from pyhpeimc.plat.device import get_dev_details


def get_vm_host_info(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostip: int or string of hostip of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: Dictionary contraining the information for the target VM host

    :rtype: dict

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> host_info = get_vm_host_info('10.101.0.6', auth.creds, auth.url)

    >>> assert type(host_info) is dict

    >>> assert len(host_info) == 10

    >>> assert 'cpuFeg' in host_info

    >>> assert 'cpuNum' in host_info

    >>> assert 'devId' in host_info

    >>> assert 'devIp' in host_info

    >>> assert 'diskSize' in host_info

    >>> assert 'memory' in host_info

    >>> assert 'parentDevId' in host_info

    >>> assert 'porductFlag' in host_info

    >>> assert 'serverName' in host_info

    >>> assert 'vendor' in host_info

    """
    hostid = get_dev_details(hostip, auth, url)['id']
    f_url = url + "/imcrs/vrm/host?hostId=" + str(hostid)
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)
        elif response.status_code == 204:
            print("Device is not a supported Hypervisor")
            return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_vm_host_info: An Error has occured"


def get_vm_host_vnic(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostip: int or string of hostip of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single NIC on the
    target host

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> host_vnic = get_vm_host_vnic('10.101.0.6', auth.creds, auth.url)

    >>> assert type(host_vnic) is list

    >>> assert (len(host_vnic[0])) is 6

    >>> assert 'ip' in host_vnic[0]

    >>> assert 'mask' in host_vnic[0]

    >>> assert 'nicName' in host_vnic[0]

    >>> assert 'serverDevId' in host_vnic[0]

    >>> assert 'vSwitchName' in host_vnic[0]

    >>> assert 'vSwtichKey' in host_vnic[0]


    """
    hostid = get_dev_details(hostip, auth, url)['id']
    f_url = url + "/imcrs/vrm/host/vnic?hostDevId=" + str(hostid)
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['Nic']
        elif response.status_code == 204:
            print("Device is not a supported Hypervisor")
            return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_vm_host_info: An Error has occured"


def get_host_vms(hostip, auth, url):
    """
    function takes hostId as input to RESTFUL call to HP IMC

    :param hostip: string of ipv4 address of Hypervisor host

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single virtual
    machine which is currently located on the target host.

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.plat.vrm import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> host_vms = get_host_vms('10.101.0.6', auth.creds, auth.url)

    >>> assert type(host_vms) is list

    >>> assert len(host_vms[0]) == 12

    >>> assert 'coresPerCpu' in host_vms[0]

    >>> assert 'cpu' in host_vms[0]

    >>> assert 'memory' in host_vms[0]

    >>> assert 'osDesc' in host_vms[0]

    >>> assert 'parentServerId' in host_vms[0]

    >>> assert 'porductFlag' in host_vms[0]

    >>> assert 'vmDevId' in host_vms[0]

    >>> assert 'vmIP' in host_vms[0]

    >>> assert 'vmMask' in host_vms[0]

    >>> assert 'vmName' in host_vms[0]

    >>> assert 'vmTools' in host_vms[0]

    """
    hostid = get_dev_details(hostip, auth, url)['id']
    f_url = url + "/imcrs/vrm/host/vm?hostId=" + str(hostid)
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(json.loads(response.text)) > 1:
                return json.loads(response.text)['vmDevice']
            else:
                return "Device is not a supported Hypervisor"
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_host_vms: An Error has occured"



# coding=utf-8
# author: @netmanchris
# -*- coding: utf-8 -*-
"""
This module contains functions for working with the access controller
capabilities of the HPE IMC WSM Module using the RESTful API

"""

# This section imports required libraries
import json

import requests

from pyhpeimc.auth import HEADERS


def get_ac_info_all(auth, url):
    """
    function takes no input as input to RESTFUL call to HP IMC

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents a single wireless
    controller which has been discovered in the HPE IMC WSM module

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.acinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> ac_info_all = get_ac_info_all(auth.creds, auth.url)

    """
    f_url = url + "/imcrs/wlan/acInfo/queryAcBasicInfo"
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['acBasicInfo']
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_ac_info_all: An Error has occured"



# coding=utf-8
# author: @netmanchris
# -*- coding: utf-8 -*-
"""
This module contains functions for working with the client information
capabilities of the HPE IMC WSM Module using the RESTful API

"""

# This section imports required libraries
import json

import requests

from pyhpeimc.auth import HEADERS


def get_client_info_all(auth, url):
    """
    function takes no input to RESTFUL call to HP IMC

    :param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents one client as
    discovered by the HPE IMC Wireless Services Management module.

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.clientinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> all_client_info = get_client_info_all(auth.creds, auth.url)

    >>> assert type(all_client_info) is list

    >>> assert len(all_client_info[0])  == 16

    >>> assert 'acDevId' in all_client_info[0]

    >>> assert 'acLabel' in all_client_info[0]

    >>> assert 'apIpAddress' in all_client_info[0]

    >>> assert 'apLabel' in all_client_info[0]

    >>> assert 'apMacAddress' in all_client_info[0]

    >>> assert 'apSerialId' in all_client_info[0]

    >>> assert 'channel' in all_client_info[0]

    >>> assert 'ipAddress' in all_client_info[0]

    >>> assert 'location' in all_client_info[0]

    >>> assert 'mac' in all_client_info[0]

    >>> assert 'radioType' in all_client_info[0]

    >>> assert 'signalStrength' in all_client_info[0]

    >>> assert 'ssid' in all_client_info[0]

    >>> assert 'upTime' in all_client_info[0]

    >>> assert 'userName' in all_client_info[0]

    """
    f_url = url +  "/imcrs/wlan/clientInfo/queryAllClientBasicInfo"
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['clientBasicInfo']
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_client_info_all: An Error has occured"


def get_client_online_history_all(auth, url):
    """
    function takes no input to RESTFUL call to HP IMC
:param auth: requests auth object #usually auth.creds from auth pyhpeimc.auth.class

    :param url: base url of IMC RS interface #usually auth.url from pyhpeimc.auth.authclass

    :return: list of dictionaries where each element of the list represents one client as
    discovered by the HPE IMC Wireless Services Management module.

    :rtype: list

    >>> from pyhpeimc.auth import *

    >>> from pyhpeimc.wsm.clientinfo import *

    >>> auth = IMCAuth("http://", "10.101.0.203", "8080", "admin", "admin")

    >>> online_client_info = get_client_online_history_all(auth.creds, auth.url)

    >>> assert type(online_client_info) is list

    >>> assert len(online_client_info[0]) == 21

    >>> assert 'acDevId' in online_client_info[0]

    >>> assert 'apName' in online_client_info[0]

    >>> assert 'apSerialId' in online_client_info[0]

    >>> assert 'authenMode' in online_client_info[0]

    >>> assert 'channel' in online_client_info[0]

    >>> assert 'ciphers' in online_client_info[0]

    >>> assert 'faultTime' in online_client_info[0]

    >>> assert 'ip' in online_client_info[0]

    >>> assert 'loginTime' in online_client_info[0]

    >>> assert 'mac' in online_client_info[0]

    >>> assert 'onlineTime' in online_client_info[0]

    >>> assert 'position' in online_client_info[0]

    >>> assert 'radioId' in online_client_info[0]

    >>> assert 'radioType' in online_client_info[0]

    >>> assert 'rxByte' in online_client_info[0]

    >>> assert 'rxNoise' in online_client_info[0]

    >>> assert 'rxSnr' in online_client_info[0]

    >>> assert 'singalStrength' in online_client_info[0]

    >>> assert 'ssid' in online_client_info[0]

    >>> assert 'txByte' in online_client_info[0]

    >>> assert 'userName' in online_client_info[0]

    """
    f_url = url + "/imcrs/wlan/clientInfo/queryClientOnlineHistoryInfo"
    response = requests.get(f_url, auth=auth, headers=HEADERS)
    try:
        if response.status_code == 200:
            if len(response.text) > 0:
                return json.loads(response.text)['clientOnlineHistoryInfo']
    except requests.exceptions.RequestException as error:
        return "Error:\n" + str(error) + " get_client_online_history_all: An Error has occured"
